@@ -5,6 +5,7 @@ from typing import Generator, List, Optional, Tuple, Union
 from ...constants.api import MAX_PAGE_SIZE
 from ...exceptions import ApiError, NotFoundError
 from ...parsers.tables import tablize_users
+from ...tools import coerce_bool
 from .. import json_api
 from ..api_endpoints import ApiEndpoints
 from ..mixins import ModelMixins
@@ -99,9 +100,11 @@ class SystemUsers(ModelMixins):
         name: str,
         password: str,
         role_name: str,
-        first: str = "",
-        last: str = "",
+        first_name: str = "",
+        last_name: str = "",
         email: str = "",
+        generate_password_link: bool = False,
+        email_password_link: bool = False,
     ) -> dict:
         """Create a user.
 
@@ -125,14 +128,23 @@ class SystemUsers(ModelMixins):
             name: user name
             password: password
             role_name: role name
-            first: first name
-            last: last name
+            first_name: first name
+            last_name: last name
             email: email address
+            generate_password_link: create a password reset link
+            email_password_link: email the password reset link to a users configured email address
 
         Raises:
             :exc:`ApiError`: if user already exists matching name
         """
+        if not any([password, generate_password_link, email_password_link]):
+            raise ApiError("Must supply password, generate_password_link, or email_password_link")
+
+        if email_password_link and not email:
+            raise ApiError("Must supply email if email_password_link is True")
+
         role = self.roles.get_by_name(name=role_name)
+
         try:
             self.get_by_name(name=name)
             raise ApiError(f"User with name of {name!r} already exists")
@@ -143,11 +155,28 @@ class SystemUsers(ModelMixins):
             user_name=name,
             role_id=role["uuid"],
             password=password,
-            first_name=first,
-            last_name=last,
+            first_name=first_name,
+            last_name=last_name,
             email=email,
+            auto_generated_password=generate_password_link,
         )
-        return self.get_by_name(name=name)
+
+        new_user = self.get_by_name(name)
+
+        if generate_password_link or email_password_link:
+            password_reset_link = self.get_password_reset_link(name)
+            new_user["password_reset_link"] = password_reset_link
+            if email_password_link:
+                try:
+                    self.email_password_reset_link(
+                        name, email=email, for_new_user=True, link=password_reset_link
+                    )
+                except Exception as exc:
+                    new_user["email_password_link_error"] = (
+                        getattr(getattr(exc, "response", None), "text", None) or exc
+                    )
+
+        return new_user
 
     def set_role(self, name: str, role_name: str) -> dict:
         """Change the role of a user.
@@ -238,7 +267,10 @@ class SystemUsers(ModelMixins):
             enabled: enable/disable the flag
         """
         return self._update_user_attr(
-            name=name, must_be_internal=False, attr="ignore_role_assignment_rules", value=enabled
+            name=name,
+            must_be_internal=False,
+            attr="ignore_role_assignment_rules",
+            value=coerce_bool(obj=enabled),
         )
 
     def delete_by_name(self, name: str) -> str:
@@ -284,10 +316,7 @@ class SystemUsers(ModelMixins):
         return self._tokens_generate(uuid=user["uuid"], user_name=user["user_name"])
 
     def email_password_reset_link(
-        self,
-        name: str,
-        email: Optional[str] = None,
-        for_new_user: bool = False,
+        self, name: str, email: Optional[str] = None, for_new_user: bool = False, link: str = ""
     ) -> Tuple[str, str]:
         """Email a password reset link for a user.
 
@@ -328,7 +357,7 @@ class SystemUsers(ModelMixins):
                 address. required if the user has no defined email address.
             for_new_user: use the new user email template instead of the password reset email
                 template
-
+            link: use the specified password reset link vs a newly generated one
         """
         user = self.get_by_name(name=name)
         email = email or user.get("email")
@@ -338,7 +367,8 @@ class SystemUsers(ModelMixins):
                 f"User {name!r} has no email address defined, must supply a custom email address"
             )
 
-        link = self._tokens_generate(uuid=user["uuid"], user_name=user["user_name"])
+        if not link:
+            link = self._tokens_generate(uuid=user["uuid"], user_name=user["user_name"])
         self._tokens_notify(uuid=user["uuid"], email=email, invite=for_new_user)
         return link, email
 
@@ -359,7 +389,7 @@ class SystemUsers(ModelMixins):
         self,
         user_name: str,
         role_id: str,
-        password: str = "",  # nosec
+        password: Optional[str] = None,
         auto_generated_password: bool = False,
         first_name: str = "",
         last_name: str = "",
@@ -404,12 +434,13 @@ class SystemUsers(ModelMixins):
         user_name: str,
         role_id: str,
         password: str,
-        first_name: str,
-        last_name: str,
-        email: str,
-        last_updated: str,
-        source: str,
-        pic_name: str,
+        first_name: Optional[str] = None,
+        last_name: Optional[str] = None,
+        email: Optional[str] = None,
+        last_updated: Optional[str] = None,
+        source: Optional[str] = None,
+        pic_name: Optional[str] = None,
+        ignore_role_assignment_rules: Optional[bool] = None,
         **kwargs,
     ) -> json_api.system_users.SystemUser:
         """Direct API method to update a user.
@@ -430,6 +461,7 @@ class SystemUsers(ModelMixins):
             last_updated=last_updated,
             source=source,
             pic_name=pic_name,
+            ignore_role_assignment_rules=ignore_role_assignment_rules,
         )
         return api_endpoint.perform_request(http=self.auth.http, request_obj=request_obj)
 
