@@ -6,7 +6,7 @@ import warnings
 from typing import Dict, List, Optional
 
 from ..data import BaseData, BaseEnum
-from ..exceptions import NotFoundError
+from ..exceptions import NotFoundError, UnknownFieldSchema
 
 AGG_ADAPTER_NAME: str = "agg"
 """Short name to use for aggregated adapter"""
@@ -145,6 +145,7 @@ class Parsers(BaseEnum):
     to_str_escaped_regex = enum.auto()
     to_str_subnet = enum.auto()
     to_str_tags = enum.auto()
+    to_str_sq_name = enum.auto()
 
 
 class Types(BaseEnum):
@@ -174,6 +175,7 @@ class Formats(BaseEnum):
     os_distribution = "os-distribution"
     dynamic_field = enum.auto()
     date = enum.auto()  # added 4.5
+    sq_name = enum.auto()
 
 
 @dataclasses.dataclass
@@ -194,6 +196,7 @@ class OperatorNameMaps(BaseData):
     count_more_than: OperatorNameMap = OperatorNameMap(name="count_above", op="count_above")
     endswith: OperatorNameMap = OperatorNameMap(name="endswith", op="ends")
     equals: OperatorNameMap = OperatorNameMap(name="equals", op="equals")
+    equals_empty: OperatorNameMap = OperatorNameMap(name="equals", op="")
     exists: OperatorNameMap = OperatorNameMap(name="exists", op="exists")
     is_false: OperatorNameMap = OperatorNameMap(name="false", op="false")
     is_true: OperatorNameMap = OperatorNameMap(name="true", op="true")
@@ -221,6 +224,7 @@ class Operator(BaseData):
     template: str
     name_map: OperatorNameMap
     parser: Parsers
+    field_name_override: Optional[str] = None
 
 
 def ops_clean(operators: List[Operator], clean: List[Operator]):
@@ -277,6 +281,12 @@ class Operators(BaseData):
         template='({field} == "{aql_value}")',
         parser=Parsers.to_str_cnx_label,
     )
+    equals_str_sq_name: Operator = Operator(
+        name_map=OperatorNameMaps.equals_empty,
+        template="({{{{QueryID={aql_value}}}}})",
+        parser=Parsers.to_str_sq_name,
+        field_name_override="saved_query",
+    )
     equals_ip: Operator = Operator(
         name_map=OperatorNameMaps.equals,
         template='({field} == "{aql_value}")',
@@ -453,6 +463,14 @@ class OperatorTypeMap(BaseData):
 class OperatorTypeMaps(BaseData):
     """Operator type map that maps operators to a specific field schemas."""
 
+    string_sq_name: OperatorTypeMap = OperatorTypeMap(
+        name="string_sq_name",
+        operators=[
+            Operators.equals_str_sq_name,
+        ],
+        field_type=Types.string,
+        field_format=Formats.sq_name,
+    )
     string_cnx_label: OperatorTypeMap = OperatorTypeMap(
         name="string_cnx_label",
         operators=[
@@ -732,6 +750,7 @@ class OperatorTypeMaps(BaseData):
         items = field.get("items") or {}
         itype = items.get("type")
         iformat = items.get("format")
+        is_array = bool(itype or iformat)
 
         if fformat == Formats.dynamic_field.value:
             fformat = None
@@ -747,33 +766,17 @@ class OperatorTypeMaps(BaseData):
         }
         attrs_text = attrs_str(attrs)
 
-        valid = {}
-
         typemaps = cls.get_fields()
         for typemap in typemaps:
             type_attrs = {k: enum_val(typemap.default, k) for k in attrs}
-            valid[typemap.name] = type_attrs
             if type_attrs == attrs:
                 typemap.default.name = typemap.name
                 return typemap.default
 
-        empty_others = not any([fformat, itype, iformat])
-        if field["type"] == Types.string.value and empty_others:  # pragma: no cover
-            warnings.warn(
-                f"Unexepected string schema in field {name!r} with {attrs_text}, assuming string"
-            )
-            return OperatorTypeMaps.string
-
-        if field["type"] == Types.array.value and empty_others:  # pragma: no cover
-            warnings.warn(
-                f"Unexepected array schema in field {name!r} with {attrs_text}, "
-                f"assuming array of string"
-            )
-            return OperatorTypeMaps.array_string
-
-        err = f"Unable to map field {name!r} with {attrs_text}"
-        valid_str = "\n  ".join([f"{k}: {attrs_str(v)}" for k, v in valid.items()])
-        raise NotFoundError("\n".join([err, valid_str, err]))
+        assume = "array of string" if is_array else "string"
+        msg = f"Unexepected schema in field {name!r} with {attrs_text}, falling back to {assume}"
+        warnings.warn(message=msg, category=UnknownFieldSchema)
+        return OperatorTypeMaps.array_string if is_array else OperatorTypeMaps.string
 
     @classmethod
     def get_operator(cls, field: dict, operator: str, err: Optional[str] = None):
@@ -821,7 +824,32 @@ CUSTOM_FIELDS_MAP: Dict[str, List[dict]] = {
             "format": "connection_label",
             "type_norm": "string_cnx_label",
             "is_agg": True,
-            "selectable": False,
+            "selectable": True,
+            "expr_field_type": AGG_EXPR_FIELD_TYPE,
+            "is_details": False,
+            "is_all": False,
+        },
+        {
+            "adapter_name_raw": f"{AGG_ADAPTER_NAME}_adapter",
+            "adapter_name": AGG_ADAPTER_NAME,
+            "adapter_title": AGG_ADAPTER_TITLE,
+            "adapter_prefix": "specific_data",
+            "column_name": f"{AGG_ADAPTER_NAME}:sq",
+            "column_title": f"{AGG_ADAPTER_TITLE}: Saved Query Name",
+            "sub_fields": [],
+            "is_complex": False,
+            "is_list": False,
+            "is_root": True,
+            "parent": "root",
+            "name": "specific_data.sq",
+            "name_base": "sq",
+            "name_qual": "specific_data.sq",
+            "title": "Saved Query Name",
+            "type": "string",
+            "format": "sq_name",
+            "type_norm": "string_sq_name",
+            "is_agg": True,
+            "selectable": True,
             "expr_field_type": AGG_EXPR_FIELD_TYPE,
             "is_details": False,
             "is_all": False,
