@@ -3,7 +3,6 @@
 import os
 
 import pytest
-
 from axonius_api_client.api import (
     ActivityLogs,
     Adapters,
@@ -23,13 +22,15 @@ from axonius_api_client.api import (
     Wizard,
     WizardCsv,
     WizardText,
+    OpenAPISpec
 )
 from axonius_api_client.api.adapters import Cnx
 from axonius_api_client.api.assets import Fields, Labels, SavedQuery
 from axonius_api_client.constants.adapters import CSV_ADAPTER
 
 from .meta import CSV_FILECONTENT_STR, CSV_FILENAME, USER_NAME
-from .utils import check_apiobj, check_apiobj_children, check_apiobj_xref, get_auth, get_url
+from .utils import (check_apiobj, check_apiobj_children, check_apiobj_xref,
+                    get_auth, get_url)
 
 AX_URL = os.environ.get("AX_URL", None) or None
 AX_KEY = os.environ.get("AX_KEY", None) or None
@@ -64,7 +65,13 @@ def pytest_addoption(parser):
 def pytest_configure(config):
     """Ini file additions."""
     config.addinivalue_line("filterwarnings", "error::axonius_api_client.exceptions.AxonWarning")
+    config.addinivalue_line(
+        "filterwarnings", "default::axonius_api_client.exceptions.JsonApiIncorrectType"
+    )
     config.addinivalue_line("filterwarnings", "ignore::urllib3.exceptions.InsecureRequestWarning")
+    config.addinivalue_line(
+        "filterwarnings", "ignore::marshmallow.warnings.RemovedInMarshmallow4Warning"
+    )
 
 
 @pytest.fixture(scope="session")
@@ -310,3 +317,12 @@ def temp_user(api_system_users):
         api_system_users._delete(uuid=tuser.uuid)
     except Exception:
         pass
+
+
+@pytest.fixture(scope="session")
+def api_openapi(request):
+    """Test utility."""
+    auth = get_auth(request)
+    obj = OpenAPISpec(auth=auth)
+    check_apiobj(authobj=auth, apiobj=obj)
+    return obj
