@@ -8,7 +8,7 @@ import requests
 
 from axonius_api_client.exceptions import HttpError
 from axonius_api_client.http import Http
-from axonius_api_client.url_parser import UrlParser
+from axonius_api_client.parsers.url_parser import UrlParser
 from axonius_api_client.version import __version__
 
 from ..meta import TEST_CLIENT_CERT, TEST_CLIENT_CERT_NAME, TEST_CLIENT_KEY, TEST_CLIENT_KEY_NAME
