@@ -21,7 +21,7 @@ import dateutil.tz
 from . import INIT_DOTENV, PACKAGE_FILE, PACKAGE_ROOT, VERSION
 from .constants.api import GUI_PAGE_SIZES
 from .constants.general import (ERROR_ARGS, ERROR_TMPL, NO, OK_ARGS, OK_TMPL,
-                                WARN_ARGS, WARN_TMPL, YES)
+                                URL_STARTS, WARN_ARGS, WARN_TMPL, YES)
 from .exceptions import ToolsError
 from .setup_env import find_dotenv, get_env_ax
 
@@ -222,6 +222,17 @@ def strip_left(obj: Union[List[str], str], fix: str) -> Union[List[str], str]:
     return obj
 
 
+class AxJSONEncoder(json.JSONEncoder):
+    """Pass."""
+
+    def default(self, obj):
+        """Pass."""
+        if isinstance(obj, datetime):
+            return obj.isoformat()
+
+        return super().default(obj)
+
+
 def json_dump(
     obj: Any, indent: int = 2, sort_keys: bool = False, error: bool = True, **kwargs
 ) -> Any:
@@ -237,6 +248,9 @@ def json_dump(
     if isinstance(obj, bytes):
         obj = obj.decode("utf-8")
 
+    kwargs.setdefault("cls", AxJSONEncoder)
+    kwargs.setdefault("default", str)
+
     try:
         return json.dumps(obj, indent=indent, sort_keys=sort_keys, **kwargs)
     except Exception:
@@ -633,6 +647,11 @@ def echo_error(msg: str, abort: bool = True, tmpl: bool = True, **kwargs):
 
 def sysinfo() -> dict:
     """Gather system information."""
+    try:
+        cli_args = sys.argv
+    except Exception:
+        cli_args = "No sys.argv!"
+
     info = {}
     info["API Client Version"] = VERSION
     info["API Client Package"] = PACKAGE_FILE
@@ -641,7 +660,7 @@ def sysinfo() -> dict:
     info["OS envs"] = get_env_ax()
     info["Date"] = str(dt_now())
     info["Python System Version"] = ", ".join(sys.version.splitlines())
-    info["Command Line Args"] = sys.argv
+    info["Command Line Args"] = cli_args
     platform_attrs = [
         "machine",
         "node",
@@ -1000,3 +1019,8 @@ def combo_dicts(*args):
         if isinstance(x, dict):
             ret.update(x)
     return ret
+
+
+def is_url(value: str) -> bool:
+    """Pass."""
+    return isinstance(value, str) and any([value.startswith(x) for x in URL_STARTS])
